<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

class GVAElement_Pricing_Block extends GVAElement_Base {

	public function get_name() {
		return 'gva-pricing-block';
	}

	public function get_title() {
		return __( 'GVA Pricing Block', 'vizeon-themer' );
	}

	public function get_icon() {
		return 'eicon-type-tool';
	}

	public function get_keywords() {
		return [ 'pricing', 'block' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'vizeon-themer' ),
			]
		);

		$this->add_control(
			'title_text',
			[
				'label' => __( 'Title', 'vizeon-themer' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'vizeon-themer' ),
				'default' => __( 'Standard', 'vizeon-themer' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'price',
			[
				'label' => __( 'Price', 'vizeon-themer' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( '60.00', 'vizeon-themer' ),
				'default' => __( '60.00', 'vizeon-themer' ),
			]
		);

		$this->add_control(
			'currency',
			[
				'label' => __( 'Currency', 'vizeon-themer' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( 'Currency', 'vizeon-themer' ),
				'default' => __( '$', 'vizeon-themer' ),
			]
		);

		$this->add_control(
			'period',
			[
				'label' => __( 'Period', 'vizeon-themer' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( 'Monthly', 'vizeon-themer' ),
				'default' => __( 'Monthly', 'vizeon-themer' ),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
         'pricing_features',
         [
            'label'       => __('Pricing Features', 'potisen-themer'),
            'type'        => Controls_Manager::TEXTAREA,
            'default'     => 'Free text goes here',
            'label_block' => true,
            'rows'        => '10',
         ]
       );
		$this->add_control(
            'pricing_content',
            [
               'label'       => __('Pricing Features', 'vizeon-themer'),
               'type'        => Controls_Manager::REPEATER,
               'fields'      => $repeater->get_controls(),
               'title_field' => '{{{ pricing_features }}}',
               'default'     => array(
                  array(
                     'name'  => esc_html__( 'Free text goes here.', 'vizeon-themer' )
                  ),
                  array(
                     'name'  => esc_html__( 'Write here anything.', 'vizeon-themer' )
                  ),
                  array(
                     'name'  => esc_html__( 'Above mention it.', 'vizeon-themer' )
                  ),
                  array(
                     'name'  => esc_html__( 'Say once again.', 'vizeon-themer' )
                  ),
               ),
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section( //** Section Icon
			'section_Button',
			[
				'label' => __( 'Button', 'vizeon-themer' ),
			]
		);

		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button URL', 'vizeon-themer' ),
				'type' => Controls_Manager::URL,
			]
		);

		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'vizeon-themer' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Read More'
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_title_style',
			[
				'label' => __( 'Title', 'vizeon-themer' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Text Color', 'vizeon-themer' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gsc-heading .title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'selector' => '{{WRAPPER}} .gsc-heading .title',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_sub_title_style',
			[
				'label' => __( 'Sub Title', 'vizeon-themer' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
 
		$this->add_control(
			'sub_title_color',
			[
				'label' => __( 'Text Color', 'vizeon-themer' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gsc-heading .sub-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography_sub_title',
				'selector' => '{{WRAPPER}} .gsc-heading .sub-title',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_desc_style',
			[
				'label' => __( 'Description', 'vizeon-themer' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
 
		$this->add_control(
			'desc_color',
			[
				'label' => __( 'Text Color', 'vizeon-themer' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gsc-heading .title-desc' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography_desc',
				'selector' => '{{WRAPPER}} .gsc-heading .title-desc',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render heading widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		printf( '<div class="gva-element-%s gva-element">', $this->get_name() );
         include $this->get_template('gva-pricing-block.php');
      print '</div>';
	}

}
